@@ -34,7 +34,8 @@ from elastic_blast.util import ElbSupportedPrograms, UserReportError
 from elastic_blast.util import get_query_batch_size, config_logging
 from elastic_blast.tuner import get_db_data, SeqData, MTMode, MolType
 from elastic_blast.tuner import get_mt_mode, get_num_cpus, get_batch_length
-from elastic_blast.tuner import get_machine_type, get_mem_limit
+from elastic_blast.tuner import aws_get_machine_type, aws_get_mem_limit
+from elastic_blast.tuner import gcp_get_machine_type, gcp_get_mem_limit
 from elastic_blast.base import DBSource, PositiveInteger, MemoryStr
 from elastic_blast.constants import CFG_CLOUD_PROVIDER, CFG_CP_AWS_REGION, CFG_CP_GCP_REGION
 from elastic_blast.constants import ELB_DFLT_GCP_REGION, ELB_DFLT_AWS_REGION
@@ -43,7 +44,7 @@ from elastic_blast.constants import CFG_BLAST_DB, CFG_BLAST_PROGRAM, CFG_BLAST_B
 from elastic_blast.constants import CFG_BLAST_OPTIONS, CFG_CLUSTER_NUM_CPUS
 from elastic_blast.constants import CFG_CLUSTER_MACHINE_TYPE
 from elastic_blast.constants import CFG_BLAST_MEM_LIMIT
-from elastic_blast.constants import MolType, INPUT_ERROR
+from elastic_blast.constants import MolType, INPUT_ERROR, CSP
 
 
 DESC = r"""This application's purpose is to provide suggestions to run help run
@@ -62,29 +63,34 @@ def main():
         options = '' if args.options is None else args.options
         SECTIONS = [ CFG_CLOUD_PROVIDER, CFG_BLAST, CFG_CLUSTER ]
         conf = { s : {} for s in SECTIONS }
+        cloud_provider = CSP[args.csp_target]
+        sp = ElbSupportedPrograms()
+
+        db_source = DBSource[cloud_provider.name] if not args.db_source else DBSource[args.db_source]
+
+        if args.db_mem_limit_factor is None:
+            db_mem_limit_factor = 0.0 if cloud_provider == CSP.AWS else 1.1
+        else:
+            db_mem_limit_factor = args.db_mem_limit_factor
 
         if args.db is not None:
-            db_source = DBSource[args.db_source]
-            db_data = get_db_data(args.db, args.dbtype, db_source)
+            db_data = get_db_data(args.db, sp.get_db_mol_type(args.program),
+                                  db_source)
             conf[CFG_BLAST][CFG_BLAST_DB] = args.db
 
-        if db_source == DBSource.NCBI:
-            if not args.csp_target:
-                raise UserReportError(INPUT_ERROR, f"You must specify a Cloud Service Provider for db-source NCBI")
-            db_source = DBSource[args.csp_target]
-
         if not args.region:
-            if db_source == DBSource.AWS:
+            if cloud_provider == CSP.AWS:
                 args.region = ELB_DFLT_AWS_REGION
             else:
                 args.region = ELB_DFLT_GCP_REGION
 
-        if db_source == DBSource.AWS:
+        if cloud_provider == CSP.AWS:
             conf[CFG_CLOUD_PROVIDER][CFG_CP_AWS_REGION] = args.region
         else:
             conf[CFG_CLOUD_PROVIDER][CFG_CP_GCP_REGION] = args.region
 
-        query_data = SeqData(args.total_query_length, MolType(args.query_mol_type.lower()))
+        query_data = SeqData(args.total_query_length,
+                             sp.get_query_mol_type(args.program))
         mt_mode = get_mt_mode(args.program, args.options, db_data, query_data)
         options += f' {mt_mode}'
 
@@ -99,28 +105,37 @@ def main():
 
         conf[CFG_CLUSTER][CFG_CLUSTER_NUM_CPUS] = str(num_cpus)
 
-        if args.with_optimal:
-            machine_type = 'optimal'
-            if db_source != DBSource.AWS:
-                raise UserReportError(INPUT_ERROR, f"optimal instance type is not allowed for {db_source}")
+        if cloud_provider == CSP.AWS:
+            mem_limit = aws_get_mem_limit(db = db_data,
+                                          const_limit = MemoryStr(f'{args.constant_mem_limit}G'),
+                                          db_factor = db_mem_limit_factor,
+                                          with_optimal = args.with_optimal)
         else:
-            machine_type = get_machine_type(db = db_data, num_cpus = num_cpus,
-                                            region = args.region)
-        conf[CFG_CLUSTER][CFG_CLUSTER_MACHINE_TYPE] = machine_type
-
-        mem_limit = get_mem_limit(db = db_data,
-                                  const_limit = MemoryStr(f'{args.constant_mem_limit}G'),
-                                  db_factor = args.db_mem_limit_factor,
-                                  with_optimal = args.with_optimal)
+            # Currently one job per instance is assumed in GCP
+            mem_limit = gcp_get_mem_limit(db = db_data,
+                                          db_factor = db_mem_limit_factor)
         conf[CFG_BLAST][CFG_BLAST_MEM_LIMIT] = mem_limit
 
-        print('Please consider the following ElasticBLAST configuration settings:\n')
+        if args.with_optimal:
+            machine_type = 'optimal'
+            if cloud_provider != CSP.AWS:
+                raise UserReportError(INPUT_ERROR, f'The "optimal" instance type is only allowed for AWS')
+        else:
+            if cloud_provider == CSP.AWS:
+                machine_type = aws_get_machine_type(db = db_data,
+                                                    num_cpus = num_cpus,
+                                                    region = args.region)
+            else:
+                machine_type = gcp_get_machine_type(mem_limit = mem_limit,
+                                                     num_cpus = num_cpus)
+
+        conf[CFG_CLUSTER][CFG_CLUSTER_MACHINE_TYPE] = machine_type
 
         for section in SECTIONS:
-            print(f'\t[{section}]')
+            print(f'[{section}]', file=args.out)
             for key, value in sorted(conf[section].items(), key=lambda x: x[0]):
-                print(f'\t{key} = {value}')
-            print('')
+                print(f'{key} = {value}', file=args.out)
+            print('', file=args.out)
 
         return 0
     except UserReportError as err:
@@ -138,24 +153,18 @@ def create_arg_parser():
     optional = parser.add_argument_group('optional arguments')
 
     required.add_argument("--db", type=str, help="BLAST database to search", required=True)
-    required.add_argument("--dbtype", type=str, 
-            choices=MolType.valid_choices(), required=True,
-            help="Molecule type of the BLAST database")
     required.add_argument("--program", type=str, help="BLAST program to run",
                         choices=ElbSupportedPrograms().get(), required=True)
     required.add_argument("--total-query-length", type=PositiveInteger, required=True,
                         help='Number of residues or bases in query sequecnes')
-    required.add_argument("--query-mol-type", type=str,
-                        help='Query molecular type',
-                        choices=MolType.valid_choices(), required=True)
+    required.add_argument("--csp-target", type=str, help="Which Cloud Service Provider to use, default: AWS", choices=['AWS', 'GCP'], default='AWS')
+    required.add_argument('--out', type=argparse.FileType('w'), help='Save configuration in this file', default='-')
 
-    optional.add_argument("--db-source", type=str, help="Where NCBI-provided databases are downloaded from, default: AWS", choices=['AWS', 'GCP', 'NCBI'], default='AWS')
-    optional.add_argument("--csp-target", type=str, help="Which Cloud Service Provider to use, applicable for db-source NCBI, default: AWS", choices=['AWS', 'GCP'], default='AWS')
+    optional.add_argument("--db-source", type=str, help="Where NCBI-provided databases are downloaded from, default: AWS", choices=['AWS', 'GCP', 'NCBI'])
     optional.add_argument("--region", type=str, help=f'Cloud Service Provider region. Defaults: {ELB_DFLT_AWS_REGION} for AWS; {ELB_DFLT_GCP_REGION} for GCP')
     optional.add_argument("--options", type=str, help='BLAST options', default='')
     optional.add_argument("--db-mem-limit-factor", type=float,
-                          help='This number times database bytes-to-cache will produce memory limit for a BLAST search',
-                          default=0.0)
+                          help='This number times database bytes-to-cache will produce memory limit for a BLAST search. (default: 0.0: for AWS, 1.1 for GCP)')
     optional.add_argument("--constant-mem-limit", type=int, help='A constant memory limit for all search jobs in GB', default='20')
     optional.add_argument("--with-optimal", action='store_true',
                          help='Use AWS optimal instance type')
