@@ -45,7 +45,6 @@ cat >$exclusions<<EOF
 share
 demo
 setenv.sh
-blast-tuner.py
 elb-cost.py
 cost.py
 gcp_ram_size.py
@@ -54,6 +53,7 @@ README-ncbi.md
 README-blast-tuner.md
 performance
 Makefile-pypi
+docker-blast/README.md
 EOF
 
 if [ "$branch"  = "latest" ] ; then
@@ -73,6 +73,7 @@ share/etc/elastic-blast-aws-iam-policy.json.template
 share/etc/yamllint-config.yaml
 share/etc/elb-aws-blastn-nt-8-nodes.ini
 share/etc/elb-blastp-nr.ini
+share/tools/cleanup-stale-gcp-resources.py
 EOF
 rsync -Cva --files-from=$inclusions $src/ $dst/
 
